cider.nrepl.middleware.info


blacklistclj

(blacklist info)

Remove anything that might contain arbitrary EDN, metadata can hold anything.

Remove anything that might contain arbitrary EDN, metadata can hold anything.
sourceraw docstring

classify-symbolsclj

(classify-symbols {:keys [symbols] :as msg})

Classify each symbol string in :symbols, resolved in :ns. Returns a map from symbol string to its kind ("macro", "inline", "special" or "function"); symbols that don't resolve are omitted.

Classify each symbol string in `:symbols`, resolved in `:ns`.
Returns a map from symbol string to its kind ("macro", "inline",
"special" or "function"); symbols that don't resolve are omitted.
sourceraw docstring

classify-symbols-replyclj

(classify-symbols-reply msg)
source

dissoc-nil-keysclj

(dissoc-nil-keys info)

Dissociate keys which has nil as a value to avoid returning empty list as a nil. nrepl.bencode converts nil to empty list.

Dissociate keys which has nil as a value to avoid returning empty list as a nil.
nrepl.bencode converts nil to empty list.
sourceraw docstring

eldoc-datomic-query-replyclj

(eldoc-datomic-query-reply {:keys [ns sym symbol]})
source

eldoc-replyclj

(eldoc-reply msg)
source

format-nestedclj

(format-nested info)

Apply response formatting to nested :candidates info for Java members.

Apply response formatting to nested `:candidates` info for Java members.
sourceraw docstring

format-responseclj

(format-response info)
source

handle-infoclj

(handle-info handler msg)
source

infoclj

(info {:keys [ns sym class member context var-meta-allowlist
              download-sources-jar]
       legacy-sym :symbol
       :as msg})
source

info-replyclj

(info-reply msg)
source

var-meta-allowlist-setclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries