cider.nrepl.middleware.test

Test execution, reporting, and inspection

Test execution, reporting, and inspection
raw docstring

*test-error-handler*clj

A function you can override via binding, or safely via alter-var-root. On test :errors, the related Throwable be invoked as the sole argument passed to this var. For example, you can use this to add an additional println, for pretty-printing Spec failures. Remember to flush if doing so.

A function you can override via `binding`, or safely via `alter-var-root`.
On test `:error`s, the related Throwable be invoked as the sole argument
passed to this var.
For example, you can use this to add an additional `println`,
for pretty-printing Spec failures. Remember to `flush` if doing so.
sourceraw docstring

current-reportcljdeprecated

source

handle-retest-opclj

(handle-retest-op {:keys [session id] :as msg})
source

handle-stacktrace-opclj

(handle-stacktrace-op {:keys [ns var index session id] :as msg})
source

handle-testclj

(handle-test handler msg & _configuration)
source

handle-test-all-opclj

(handle-test-all-op {:keys [load? include exclude] :as msg})
source

handle-test-opclj

(handle-test-op {:keys [ns tests include exclude] :as msg})
source

handle-test-var-query-opclj

(handle-test-var-query-op {:keys [var-query session id] :as msg})
source

reportcljmultimethoddeprecated

source

report-fixture-errorcljdeprecated

source

resultsclj

An atom holding results of test runs, indexed by namespace. This is used to reference exception objects from erring tests, and to rerun tests (by namespace) that did not pass previously. The var itself will be bound from the nREPL session.

An atom holding results of test runs, indexed by namespace. This is used to
reference exception objects from erring tests, and to rerun tests (by
namespace) that did not pass previously. The var itself will be bound from
the nREPL session.
sourceraw docstring

stack-framecljdeprecated

source

test-nsscljdeprecated

(test-nss m)
(test-nss m fail-fast?)

Use orchard.test/run-namespaces instead.

Use `orchard.test/run-namespaces` instead.
sourceraw docstring

test-resultcljdeprecated

source

test-varcljdeprecated

source

test-var-querycljdeprecated

(test-var-query var-query)
(test-var-query var-query fail-fast?)

Use orchard.test/run-var-query instead.

Use `orchard.test/run-var-query` instead.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries