cider.nrepl.middleware.trace


handle-traceclj

(handle-trace handler msg)
source

list-tracedclj

(list-traced _msg)

Return the currently traced vars and namespaces, as strings.

Return the currently traced vars and namespaces, as strings.
sourceraw docstring

toggle-trace-nsclj

(toggle-trace-ns {:keys [ns]})
source

toggle-trace-varclj

(toggle-trace-var {:keys [ns sym]})
source

trace-subscribeclj

(trace-subscribe msg)

Stream trace events to the client until cider/trace-unsubscribe. Registers an orchard trace listener that forwards each event on this request, and routes trace output to listeners instead of the REPL.

Stream trace events to the client until `cider/trace-unsubscribe`.
Registers an orchard trace listener that forwards each event on this
request, and routes trace output to listeners instead of the REPL.
sourceraw docstring

trace-unsubscribeclj

(trace-unsubscribe {:keys [subscription]})

Stop streaming trace events for the given subscription. Restores REPL trace output once the last subscription is gone.

Stop streaming trace events for the given subscription.
Restores REPL trace output once the last subscription is gone.
sourceraw docstring

untrace-allclj

(untrace-all _msg)

Untrace every currently traced var and namespace. Returns the number of vars that were untraced.

Untrace every currently traced var and namespace.
Returns the number of vars that were untraced.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries