Utility functions for extracting and manipulating metadata.
Utility functions for extracting and manipulating metadata.
(relevant-meta m)Filter the entries in map m by relevant-meta-keys and non-nil values.
Filter the entries in map m by `relevant-meta-keys` and non-nil values.
Metadata keys that are useful to us. This is used so that we don't crowd the ns cache with useless or redudant information, such as :name and :ns.
Metadata keys that are useful to us. This is used so that we don't crowd the ns cache with useless or redudant information, such as :name and :ns.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |