cider.nrepl.middleware.util.nrepl

Common nREPL-related utilities.

Common nREPL-related utilities.
raw docstring

notify-clientclj

(notify-client notification)
(notify-client msg notification)
(notify-client msg notification type)
(notify-client tr msg notification type)

Send user level notification to client as a response to request msg. If transport is not provided use (:transport msg). If msg is not provided, use current msg from interruptible-eval middleware. Type is a keyword or string indicating type of the message (e.g. :message, :warning, :error etc). Type defaults to :message. See nrepl-notify on the Emacs side.

Send user level notification to client as a response to request `msg`.
If transport is not provided use (:transport msg). If msg is not provided, use
current *msg* from interruptible-eval middleware. Type is a keyword or string
indicating type of the message (e.g. :message, :warning, :error etc). Type
defaults to :message. See `nrepl-notify` on the Emacs side.
sourceraw docstring

satisfies-version?clj

(satisfies-version? major minor)

Check if the nREPL version is of the provided major and minor parts or newer.

Check if the nREPL version is of the provided major and minor parts or newer.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries