(blacklist info)Remove anything that might contain arbitrary EDN, metadata can hold anything.
Remove anything that might contain arbitrary EDN, metadata can hold anything.
(classify-symbols {:keys [symbols] :as msg})Classify each symbol string in :symbols, resolved in :ns.
Returns a map from symbol string to its kind ("macro", "inline",
"special" or "function"); symbols that don't resolve are omitted.
Classify each symbol string in `:symbols`, resolved in `:ns`.
Returns a map from symbol string to its kind ("macro", "inline",
"special" or "function"); symbols that don't resolve are omitted.(dissoc-nil-keys info)Dissociate keys which has nil as a value to avoid returning empty list as a nil. nrepl.bencode converts nil to empty list.
Dissociate keys which has nil as a value to avoid returning empty list as a nil. nrepl.bencode converts nil to empty list.
(format-nested info)Apply response formatting to nested :candidates info for Java members.
Apply response formatting to nested `:candidates` info for Java members.
(info {:keys [ns sym class member context var-meta-allowlist
download-sources-jar]
legacy-sym :symbol
:as msg})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |