Test execution, reporting, and inspection
Test execution, reporting, and inspection
A function you can override via binding, or safely via alter-var-root.
On test :errors, the related Throwable be invoked as the sole argument
passed to this var.
For example, you can use this to add an additional println,
for pretty-printing Spec failures. Remember to flush if doing so.
A function you can override via `binding`, or safely via `alter-var-root`. On test `:error`s, the related Throwable be invoked as the sole argument passed to this var. For example, you can use this to add an additional `println`, for pretty-printing Spec failures. Remember to `flush` if doing so.
An atom holding results of test runs, indexed by namespace. This is used to reference exception objects from erring tests, and to rerun tests (by namespace) that did not pass previously. The var itself will be bound from the nREPL session.
An atom holding results of test runs, indexed by namespace. This is used to reference exception objects from erring tests, and to rerun tests (by namespace) that did not pass previously. The var itself will be bound from the nREPL session.
(test-nss m)(test-nss m fail-fast?)Use orchard.test/run-namespaces instead.
Use `orchard.test/run-namespaces` instead.
(test-var-query var-query)(test-var-query var-query fail-fast?)Use orchard.test/run-var-query instead.
Use `orchard.test/run-var-query` instead.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |