(list-traced _msg)Return the currently traced vars and namespaces, as strings.
Return the currently traced vars and namespaces, as strings.
(trace-subscribe msg)Stream trace events to the client until cider/trace-unsubscribe.
Registers an orchard trace listener that forwards each event on this
request, and routes trace output to listeners instead of the REPL.
Stream trace events to the client until `cider/trace-unsubscribe`. Registers an orchard trace listener that forwards each event on this request, and routes trace output to listeners instead of the REPL.
(trace-unsubscribe {:keys [subscription]})Stop streaming trace events for the given subscription. Restores REPL trace output once the last subscription is gone.
Stop streaming trace events for the given subscription. Restores REPL trace output once the last subscription is gone.
(untrace-all _msg)Untrace every currently traced var and namespace. Returns the number of vars that were untraced.
Untrace every currently traced var and namespace. Returns the number of vars that were untraced.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |