cider.nrepl.middleware.util.cljs


cljs-response-valueclj

(cljs-response-value response)

Returns the :value slot of an eval response from piggieback as a Clojure value.

Returns the :value slot of an eval response from piggieback as a Clojure
value.
sourceraw docstring

expects-piggiebackcljdeprecated

(expects-piggieback descriptor)

Deprecated: returns the descriptor unchanged.

Deprecated: returns the descriptor unchanged.
sourceraw docstring

grab-cljs-envclj

(grab-cljs-env msg)

If piggieback is active, returns the ClojureScript compiler environment for the running REPL.

If piggieback is active, returns the ClojureScript compiler environment for
the running REPL.
sourceraw docstring

grab-cljs-env*clj

(grab-cljs-env* msg)
source

maybe-add-piggiebackclj

(maybe-add-piggieback coll)

If piggieback is loaded, conj piggieback mw var to the provided collection.

If piggieback is loaded, conj piggieback mw var to the provided collection.
sourceraw docstring

requires-piggiebackcljdeprecated

(requires-piggieback descriptor)

Deprecated: returns the descriptor unchanged.

Deprecated: returns the descriptor unchanged.
sourceraw docstring

response-valueclj

(response-value msg response)

Returns the :value slot of an eval response as a Clojure value, reading the slot if necessary (piggieback 0.2.x).

Returns the :value slot of an eval response as a Clojure value, reading the
slot if necessary (piggieback 0.2.x).
sourceraw docstring

try-resolve-piggiebackclj

(try-resolve-piggieback)

If piggieback is loaded, return #'cider.piggieback/wrap-cljs-repl, nil otherwise.

If piggieback is loaded, return `#'cider.piggieback/wrap-cljs-repl`, nil
otherwise.
sourceraw docstring

with-cljs-envcljmacro

(with-cljs-env msg & body)
source

with-cljs-nscljmacro

(with-cljs-ns ns-sym & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries