(cljs-response-value response)Returns the :value slot of an eval response from piggieback as a Clojure value.
Returns the :value slot of an eval response from piggieback as a Clojure value.
(expects-piggieback descriptor)Deprecated: returns the descriptor unchanged.
Deprecated: returns the descriptor unchanged.
(grab-cljs-env msg)If piggieback is active, returns the ClojureScript compiler environment for the running REPL.
If piggieback is active, returns the ClojureScript compiler environment for the running REPL.
(maybe-add-piggieback coll)If piggieback is loaded, conj piggieback mw var to the provided collection.
If piggieback is loaded, conj piggieback mw var to the provided collection.
(requires-piggieback descriptor)Deprecated: returns the descriptor unchanged.
Deprecated: returns the descriptor unchanged.
(response-value msg response)Returns the :value slot of an eval response as a Clojure value, reading the slot if necessary (piggieback 0.2.x).
Returns the :value slot of an eval response as a Clojure value, reading the slot if necessary (piggieback 0.2.x).
(try-resolve-piggieback)If piggieback is loaded, return #'cider.piggieback/wrap-cljs-repl, nil
otherwise.
If piggieback is loaded, return `#'cider.piggieback/wrap-cljs-repl`, nil otherwise.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |