Common nREPL-related utilities.
Common nREPL-related utilities.
(notify-client notification)(notify-client msg notification)(notify-client msg notification type)(notify-client tr msg notification type)Send user level notification to client as a response to request msg.
If transport is not provided use (:transport msg). If msg is not provided, use
current msg from interruptible-eval middleware. Type is a keyword or string
indicating type of the message (e.g. :message, :warning, :error etc). Type
defaults to :message. See nrepl-notify on the Emacs side.
Send user level notification to client as a response to request `msg`. If transport is not provided use (:transport msg). If msg is not provided, use current *msg* from interruptible-eval middleware. Type is a keyword or string indicating type of the message (e.g. :message, :warning, :error etc). Type defaults to :message. See `nrepl-notify` on the Emacs side.
(satisfies-version? major minor)Check if the nREPL version is of the provided major and minor parts or newer.
Check if the nREPL version is of the provided major and minor parts or newer.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |