Pretty-print related utilities. All functions here are simple wrappers compatible with the expectations of nrepl.middleware.print/wrap-print.
Pretty-print related utilities. All functions here are simple wrappers compatible with the expectations of nrepl.middleware.print/wrap-print.
(clojure-pprint value writer)(clojure-pprint value writer options)Pretty-print value with clojure.pprint/write. Prefer pprint (backed by
orchard.pp); this is kept for callers that specifically want
clojure.pprint's output, but note that it realizes lazy seqs as it prints.
Pretty-print `value` with `clojure.pprint/write`. Prefer `pprint` (backed by `orchard.pp`); this is kept for callers that specifically want `clojure.pprint`'s output, but note that it realizes lazy seqs as it prints.
(orchard-pprint value writer)(orchard-pprint value writer options)Alias of pprint; both are backed by orchard.pp.
Alias of `pprint`; both are backed by `orchard.pp`.
(pprint value writer)(pprint value writer options)Pretty-print value using orchard.pp. Unlike clojure.pprint, it does not
realize lazy sequences while printing, so it won't interleave their side
effects into - and corrupt - the printed result (see #903). Honors the usual
:length, :level and :right-margin print options.
Pretty-print `value` using `orchard.pp`. Unlike `clojure.pprint`, it does not realize lazy sequences while printing, so it won't interleave their side effects into - and corrupt - the printed result (see #903). Honors the usual `:length`, `:level` and `:right-margin` print options.
(pr value writer)(pr value writer options)Equivalent to clojure.core/pr. Any options corresponding to dynamic
printing configuration vars in clojure.core will, if provided, be bound
accordingly (e.g. clojure.core/*print-length* will be used if
:print-length is provided).
Equivalent to `clojure.core/pr`. Any options corresponding to dynamic printing configuration vars in `clojure.core` will, if provided, be bound accordingly (e.g. `clojure.core/*print-length*` will be used if `:print-length` is provided).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |